<div class="row justify-content-center mt-2 sight-height">  
    {% for obj in url %}
        <div class="col-lg-4">
            <img class="rounded sight-image" src="{{obj}}" alt="stelaSight Image Generator">
        </div>
        
    {% endfor %}    
</div>