{% load i18n %}
{% load crispy_forms_tags %}
<div class="container">
    <div class="row">
        {{form|crispy}}
    </div>
    <div id="formset">
        {{ formset.management_form }}
        {% for form in formset %}
            <div id="form-0" class="formset pt-2">
                <div class="row">
                    {{form|crispy}}
                </div>
            </div>
        {% endfor %}
    </div>
    <div class="d-flex justify-content-between my-3">
        <button class="btn-clear" onclick="addFAQCKE()" type="button"><i class="fa-solid fa-plus"></i> {% trans "Add" %}</button>
        <button class="btn-clear remove-formset" onclick="clearFAQCKE()" type="button"><i class="fa-solid fa-minus"></i> {% trans "Remove" %}</button>
    </div>
    <div id="empty-form" class="d-none">
        <div class="row">
            {{formset.empty_form|crispy}}
        </div>
    </div>
</div>
<p class="response-footer text-link fw-bold oxanium"></p>
<input type="hidden" name="form-id" value="faq-form">